@@ -36,8 +36,14 @@
 
 __BEGIN_DECLS
 
-void gsl_sort_long_double (long double * data, size_t stride, size_t n);
-int gsl_sort_long_double_index (size_t * p, const long double * data, size_t stride, size_t n);
+void gsl_sort_long_double (long double * data, const size_t stride, const size_t n);
+void gsl_sort_long_double_index (size_t * p, const long double * data, const size_t stride, const size_t n);
+
+int gsl_sort_long_double_smallest (long double * dest, const size_t k, const long double * src, const size_t stride, const size_t n);
+int gsl_sort_long_double_smallest_index (size_t * p, const size_t k, const long double * src, const size_t stride, const size_t n);
+
+int gsl_sort_long_double_largest (long double * dest, const size_t k, const long double * src, const size_t stride, const size_t n);
+int gsl_sort_long_double_largest_index (size_t * p, const size_t k, const long double * src, const size_t stride, const size_t n);
 
 __END_DECLS
 
